 #####################################
###                                 ###
##          www.TheVWAP.com          ##
###                                 ###
 #####################################
##
##  TheVWAP_Boulevard [v1.4]
##  code © Zach Hurwitz / idea credit to AllDayFaders (twtr: @team3dstocks)
##  September 14th, 2021
##
##  email:   Zach@TheVWAP.com  or  Support@TheVWAP.com
##  twitter: @ZachHurwitz      or  @TheVWAP
##  web:     www.TheVWAP.com   or  www.TheVWAP.com/vwap-boulevard/

#hint: TheVWAP_Boulevard automatically launches static or dynamic VWAPs from up to the three highest volume instances available on the user's chart.  Allows for highest-volume-Bar or highest-volume-Day detection.  Popularized by Twitter user AllDayFaders (@team3dstocks) in 2021.

#hint Mode: Choose from different methods specifying the range and type of highVol search (and VWAP calculation) used.\n<li><b>[max] DAYS — Static</b>: <b>{default}</b> Popularized by @team3dstocks, this seeks highest volume days (regardless of their presence on the visible chart, or before) within the user-specified length [default = 250] and records the corresponding daily VWAP as a constant.</li>\n<li><b>[chart] DAYS — Static</b>: Popularized by @team3dstocks, this seeks highest volume days <b>on the total available, current chart ONLY</b> and records the corresponding daily VWAP as a constant.</li>\n<li><b>[chart] DAYS — Live</b>: Same as above, but with continuous (live, ongoing) VWAPs from qualifying highVol days.</li>\n<li><b>[chart] BARS — Static</b>: This searches for the highest volume BARS (rather than days) on the available chart, presenting recorded VWAP values from each qualifying bar.</li>\n<li><b>[chart] BARS — Live</b>: Seeking highest volume bars, but with continuous (live, ongoing) VWAPs.</li> 
#hint VWAP_Count: Choose how many High Volume instance VWAPs to display.  Selecting more than "One" engages detection for <b>up to the three next sequentially highest-volume instances</b> smaller than the primary (highest volume) event, either for the visible chart (or beyond, when 'Mode' is set to [max search] DAYS — Static VWAP).
#hint Display_Extras: Select additional identifying <b>Labels</b> (along the upper chart edge, just under the title bar), <b>Lines</b> (appearing vertically on the price chart), <b>Both</b>, <b>or None</b>.
#hint length: The number of days backwards (current day = 0; default length = 250 days) over which the [max search] DAYS — Static VWAP mode seeks for qualifying high-volume events.
#hint show_Today_Only: Displays target bar or day levels <b>ONLY</b> on the current trading day.  This does not impact computation; only display.
#hint show_Bubbles: Display chart bubbles showing the name of each VWAP for easy visual identification.
#hint show_Search_Range: Display a vertical line to signify the beginning of the search range when in [max search] DAYS — Static VWAP mode.

DefineGlobalColor("VWAP Boulevard", Color.ORANGE);
DefineGlobalColor("2nd VWAP Boulevard",CreateColor(255,0,0));
DefineGlobalColor("3rd VWAP Boulevard",CreateColor(136,88,255));

input Mode = {default "• [max search]     DAYS  —  Static VWAP •", "      [chart only]    DAYS  —  Static VWAP", "        [chart only]  BARS  —  Static VWAP", "      [chart only]    DAYS  —     Live VWAP", "        [chart only]  BARS  —     Live VWAP"};
def typeID = if Mode == Mode."      [chart only]    DAYS  —     Live VWAP" then 2 else if Mode == Mode."        [chart only]  BARS  —  Static VWAP" then 3 else if Mode == Mode."        [chart only]  BARS  —     Live VWAP" then 4 else if Mode == Mode."      [chart only]    DAYS  —  Static VWAP" then 5 else 6;
def DayBarChoice = typeID == 2 or typeID == 5 or typeID == 6;    def ContStat = typeID == 2 or typeID == 4;    def IndepDyn = typeID == 6;

def newDay = CompoundValue(1, GetYYYYMMDD() != GetYYYYMMDD()[1] and !IsNaN(close), yes);
def dateID = If(BarNumber() > 1, dateID[1] + newDay, 1); def isLast = IsNaN(close[-1]) and !IsNaN(close);
def v_days_rolled = TotalSum(newDay); def isToday = GetDay() == GetLastDay(); def show_Spacers = yes;
def highestDaysRolled = HighestAll(v_days_rolled); def v = volume;
def vDay = volume(period = AggregationPeriod.DAY); def vwDay = vwap(period = aggregationperiod.DAY);
def barNo = BarNumber(); def lastDateID = HighestAll(isLast * dateID); def maxBarNo = HighestAll(isLast * barNo);
def NaN = Double.NaN; def DayAgg = GetAggregationPeriod() >= AggregationPeriod.DAY; 
def DayBarVWAP = !ContStat and !DayBarChoice; def altV = DayAgg or DayBarVWAP; 

input VWAP_Count = { default "Three", "Two", "One"};
def VWno = If VWAP_Count == VWAP_Count."Three" then 3 else if VWAP_Count == VWAP_Count."Two" then 2 
else if VWAP_Count == VWAP_Count."One" then 1 else Double.NaN; def V2 = VWno < 2; def V3 = VWno < 3;

input display_Extras = {"None", "Labels", "Lines", default "Both"};
def show_Labels = display_Extras == display_Extras."Labels" or display_Extras == display_Extras."Both";
def show_Lines = display_Extras == display_Extras."Lines" or display_Extras == display_Extras."Both";
input length = 250;    input show_Today_Only = no;    input show_Bubbles = no;    input show_Search_Range = no;

script customGetMaxValueOffset{
    input Data = close;
    input rangeStart = 25;
    input rangeEnd = 0;
    def barNo = BarNumber();
    def isLast = IsNaN(close[-1]) and !IsNaN(close);
    def maxBarNo = HighestAll(isLast * barNo);
    def searchArray = If(Between(barNo, maxBarNo - rangeStart, maxBarNo - rangeEnd), Data, Double.NaN);
    def maxValue = HighestAll(searchArray);
    def barNoOfMaxValue = HighestAll(If(searchArray == maxValue, barNo, Double.NaN));
    plot offset = maxBarNo - barNoOfMaxValue;}

script customGetValue{
    input Data = close;
    input offset = 0;
    def barNo = BarNumber();
    def isLast = IsNaN(close[-1]) and !IsNaN(close);
    def maxBarNo = HighestAll(isLast * barNo);
    def returnValue = HighestAll(If(barNo == maxBarNo - offset, Data, Double.NaN));
    plot value = returnValue;}

def volOffset_1 = reference customGetMaxValueOffset(v, maxBarNo, 0);
def barNoHi_1 = HighestAll(isLast * customGetValue(barNo, volOffset_1));
def hiVal_1 = HighestAll(isLast * customGetValue(v, volOffset_1));

def volOffset_2 = IF(V2,nan,CompoundValue(1, if (v > volOffset_2[1] and v < hiVal_1) then v else volOffset_2[1], 0));
def seekBarNoHi_2 =  if volOffset_2 != volOffset_2[1] then barNo else seekBarNoHi_2[1];
def barNoHi_2 = HighestAll(seekBarNoHi_2); def hiVal_2 = HighestAll(isLast * volOffset_2);

def volOffset_3 = IF(V3,nan,CompoundValue(1, if (v > volOffset_3[1] and v < hiVal_2) then v else volOffset_3[1], 0));
def seekBarNoHi_3 = if volOffset_3 != volOffset_3[1] then barNo else seekBarNoHi_3[1];
def barNoHi_3 = HighestAll(seekBarNoHi_3); def hiVal_3 = HighestAll(isLast * volOffset_3);

def vol1 = fold y = 1 to length with c = 0 do if vDay[y] > c then vDay[y] else c;
def dayOff1 = fold x = 1 to length with b = 0 while vDay[x] < vol1 do if vDay[x] > b then x else b;
def vw1 = fold z = 1 to length with d = 0 do if vDay[z] == vol1 then vwDay[z] else d;
def bID1 = If(IsNaN(vw1), NaN, barNo); def vwap1 = HighestAll(If(bID1 == HighestAll(bID1), vw1, NaN));
def display1 = fold o = 1 to length with p = 0 do if vwDay[o] == vwap1 then GetYYYYMMDD()[o] else p;

def vol2 = IF(V2,nan,fold y2 = 1 to length with c2 = 0 do if vDay[y2] > c2 and vDay[y2] != vol1 then vDay[y2] else c2);
def vw2 = fold z2 = 1 to length with d2 = 0 do if vDay[z2] == vol2 and vDay[z2] != vol1 then vwDay[z2] else d2;
def bID2 = If(IsNaN(vw2), NaN, barNo); def vwap2 = HighestAll(If(bID2 == HighestAll(bID2), vw2, NaN));
def display2 = fold o2 = 1 to length with p2 = 0 do if vwDay[o2] == vwap2 then GetYYYYMMDD()[o2] else p2;

def vol3 = IF(V3,nan,fold y3 = 1 to length with c3 = 0 do if vDay[y3] > c3 and vDay[y3] != vol1 and vDay[y3] != vol2 then vDay[y3] else c3);
def vw3 = fold z3 = 1 to length with d3 = 0 do if vDay[z3] == vol3 and vDay[z3] != vol1 and vDay[z3] != vol2 then vwDay[z3] else d3;
def bID3 = If(IsNaN(vw3), NaN, barNo); def vwap3 = HighestAll(If(bID3 == HighestAll(bID3), vw3, NaN));
def display3 = fold o3 = 1 to length with p3 = 0 do if vwDay[o3] == vwap3 then GetYYYYMMDD()[o3] else p3;

def offset_1D = If(IndepDyn, maxBarNo, reference customGetMaxValueOffset(vDay, maxBarNo, 0) - IndepDyn);
def hiVal_1D = If(IndepDyn, vol1, HighestAll(isLast * customGetValue(vDay, offset_1D))); def ID_1D = If(IndepDyn, 1, HighestAll(isLast * customGetValue(dateID, offset_1D)));
def fuse_1D = CompoundValue(1, if dateID == ID_1D and dateID[1] != ID_1D then barNo else fuse_1D[1], if dateID == ID_1D then barNo else Double.POSITIVE_INFINITY);
def fuse_1De = If(IndepDyn, maxBarNo - offset_1D, CompoundValue(1, if dateID != ID_1D and dateID[1] == ID_1D then barNo else fuse_1De[1], Double.POSITIVE_INFINITY));

def vol_2D = IF(V2,nan,CompoundValue(1, if (vDay > vol_2D[1] and vDay < hiVal_1D) then vDay else vol_2D[1], 0));
def hiVal_2D = If(IndepDyn, vol2, HighestAll(isLast * vol_2D)); def bar2 = CompoundValue(1, if vDay == hiVal_2D then barNo else bar2[1], If(IndepDyn, 1, vDay == hiVal_2D));
def offset_2D = If(IndepDyn, maxBarNo, maxBarNo - bar2); def ID_2D = If(IndepDyn, 1, HighestAll(isLast * customGetValue(dateID, offset_2D)));
def fuse_2D = CompoundValue(1, if dateID == ID_2D and dateID[1] != ID_2D then barNo else fuse_2D[1], if dateID == ID_2D then barNo else Double.POSITIVE_INFINITY);
def fuse_2De = CompoundValue(1, if dateID != ID_2D and dateID[1] == ID_2D then barNo else fuse_2De[1], Double.POSITIVE_INFINITY);

def vol_3D = IF(V3,nan,CompoundValue(1, if (vDay > vol_3D[1] and vDay < hiVal_2D) then vDay else vol_3D[1], 0));
def hiVal_3D = If(IndepDyn, vol3, HighestAll(isLast * vol_3D)); def bar3 = CompoundValue(1, if vDay == hiVal_3D then barNo else bar3[1], If(IndepDyn, 1, vDay == hiVal_3D));
def offset_3D = If(IndepDyn, maxBarNo, maxBarNo - bar3); def ID_3D = If(IndepDyn, 1, HighestAll(isLast * customGetValue(dateID, offset_3D)));
def fuse_3D = CompoundValue(1, if dateID == ID_3D and dateID[1] != ID_3D then barNo else fuse_3D[1], if dateID == ID_3D then barNo else Double.POSITIVE_INFINITY);
def fuse_3De = CompoundValue(1, if dateID != ID_3D and dateID[1] == ID_3D then barNo else fuse_3De[1], Double.POSITIVE_INFINITY);

def B1 = CompoundValue(1,if GetYYYYMMDD() == HighestAll(display1) and GetYYYYMMDD()[1] != HighestAll(display1) then barNo else B1[1],0);
def B2 = CompoundValue(1,if GetYYYYMMDD() == HighestAll(display2) and GetYYYYMMDD()[1] != HighestAll(display2) then barNo else B2[1],0);
def B3 = CompoundValue(1,if GetYYYYMMDD() == HighestAll(display3) and GetYYYYMMDD()[1] != HighestAll(display3) then barNo else B3[1],0);
def B1e = CompoundValue(1,if GetYYYYMMDD() == HighestAll(display1) and GetYYYYMMDD()[-1] != HighestAll(display1) then barNo+1 else B1e[1],0);
def B2e = CompoundValue(1,if GetYYYYMMDD() == HighestAll(display2) and GetYYYYMMDD()[-1] != HighestAll(display2) then barNo+1 else B2e[1],0);
def B3e = CompoundValue(1,if GetYYYYMMDD() == HighestAll(display3) and GetYYYYMMDD()[-1] != HighestAll(display3) then barNo+1 else B3e[1],0);
def cFuse1 = If(IndepDyn,HighestAll(B1),fuse_1D); def cFuse2 = If(IndepDyn,HighestAll(B2),fuse_2D); def cFuse3 = If(IndepDyn,HighestAll(B3),fuse_3D);
def varFuse1 = If(IndepDyn, 1, fuse_1De); def varFuse2 = If(IndepDyn, 1, fuse_2De); def varFuse3 = If(IndepDyn, 1, fuse_3De);

def i1 = If(!DayBarChoice, barNoHi_1, If(ContStat, cFuse1, varFuse1));
def i2 = If(!DayBarChoice, barNoHi_2, If(ContStat, cFuse2, varFuse2));
def i3 = If(!DayBarChoice, barNoHi_3, If(ContStat, cFuse3, varFuse3));
def VolumeSum_1 = If(barNo >= i1, CompoundValue(1, VolumeSum_1[1] + volume, volume), 0);
def VolumeSum_2 = If(barNo >= i2, CompoundValue(1, VolumeSum_2[1] + volume, volume), 0);
def VolumeSum_3 = If(barNo >= i3, CompoundValue(1, VolumeSum_3[1] + volume, volume), 0);
def MoneySum_1 = If(barNo >= i1, CompoundValue(1, MoneySum_1[1] + volume * vwap, volume * vwap), 0);
def MoneySum_2 = If(barNo >= i2, CompoundValue(1, MoneySum_2[1] + volume * vwap, volume * vwap), 0);
def MoneySum_3 = If(barNo >= i3, CompoundValue(1, MoneySum_3[1] + volume * vwap, volume * vwap), 0);

def rVWAP_1 = CompoundValue(1, if barNo >= i1 + !DayBarChoice then rVWAP_1[1] else If(altV, vwap, reference VWAP()), If(IndepDyn, vwap1, NaN));
def rVWAP_2 = CompoundValue(1, if barNo >= i2 + !DayBarChoice then rVWAP_2[1] else If(altV, vwap, reference VWAP()), If(IndepDyn, vwap2, NaN));
def rVWAP_3 = CompoundValue(1, if barNo >= i3 + !DayBarChoice then rVWAP_3[1] else If(altV, vwap, reference VWAP()), If(IndepDyn, vwap3, NaN));
def alt_rVW1 = CompoundValue(1,if(barNo == If(DayBarChoice, fuse_1De, barNoHi_1), vwap, alt_rVW1[1]),NaN);
def alt_rVW2 = CompoundValue(1,if(barNo == If(DayBarChoice, fuse_2De, barNoHi_2), vwap, alt_rVW2[1]),NaN);
def alt_rVW3 = CompoundValue(1,if(barNo == If(DayBarChoice, fuse_3De, barNoHi_3), vwap, alt_rVW3[1]),NaN);
plot rVW1 = If(IndepDyn, If(show_Today_Only, If(isToday, If(DayBarChoice, If(GetYYYYMMDD() > HighestAll(display1), vwap1, NaN), alt_rVW1), NaN), If(DayBarChoice, If(GetYYYYMMDD() > HighestAll(display1), vwap1, NaN), alt_rVW1)), If(!ContStat, If(show_Today_Only, If(isToday, If(barNo >= i1, rVWAP_1, NaN), NaN), If(barNo >= i1, rVWAP_1, NaN)), NaN));
plot rVW2 = If(IndepDyn,If(show_Today_Only, If(isToday, If(DayBarChoice,If(GetYYYYMMDD() > HighestAll(display2), vwap2, NaN),alt_rVW2), NaN), If(DayBarChoice,If(GetYYYYMMDD() > HighestAll(display2), vwap2, NaN), alt_rVW2)),If(!ContStat, If(show_Today_Only, If(isToday, If(barNo >= i2, rVWAP_2, NaN), NaN), If(barNo >= i2, rVWAP_2, NaN)), NaN));
plot rVW3 = If(IndepDyn,If(show_Today_Only, If(isToday, If(DayBarChoice,If(GetYYYYMMDD() > HighestAll(display3), vwap3, NaN),alt_rVW3), NaN), If(DayBarChoice,If(GetYYYYMMDD() > HighestAll(display3), vwap3, NaN), alt_rVW3)),If(!ContStat, If(show_Today_Only, If(isToday, If(barNo >= i3, rVWAP_3, NaN), NaN), If(barNo >= i3, rVWAP_3, NaN)), NaN));

rVW1.SetPaintingStrategy(PaintingStrategy.HORIZONTAL); rVW2.SetPaintingStrategy(PaintingStrategy.HORIZONTAL);
rVW3.SetPaintingStrategy(PaintingStrategy.HORIZONTAL);
rVW1.SetLineWeight(3); rVW2.SetLineWeight(2); rVW3.SetLineWeight(2);
rVW1.SetDefaultColor(GlobalColor("VWAP Boulevard")); rVW2.SetDefaultColor(GlobalColor("2nd VWAP Boulevard"));
rVW3.SetDefaultColor(GlobalColor("3rd VWAP Boulevard"));

def cVWAP_1 = CompoundValue(1, If(barNo >= i1, MoneySum_1 / VolumeSum_1, NaN), NaN);
def cVWAP_2 = CompoundValue(1, If(barNo >= i2, MoneySum_2 / VolumeSum_2, NaN), NaN);
def cVWAP_3 = CompoundValue(1, If(barNo >= i3, MoneySum_3 / VolumeSum_3, NaN), NaN);
plot cVW1 = If(ContStat, If(show_Today_Only, If(isToday, If(barNo >= i1, cVWAP_1, NaN), NaN), If(barNo >= i1, cVWAP_1, NaN)), NaN);
plot cVW2 = If(ContStat, If(show_Today_Only, If(isToday, If(barNo >= i2, cVWAP_2, NaN), NaN), If(barNo >= i2, cVWAP_2, NaN)), NaN);
plot cVW3 = If(ContStat, If(show_Today_Only, If(isToday, If(barNo >= i3, cVWAP_3, NaN), NaN), If(barNo >= i3, cVWAP_3, NaN)), NaN);

cVW1.SetLineWeight(3); cVW2.SetLineWeight(2); cVW3.SetLineWeight(2);
cVW1.SetDefaultColor(GlobalColor("VWAP Boulevard")); cVW2.SetDefaultColor(GlobalColor("2nd VWAP Boulevard")); cVW3.SetDefaultColor(GlobalColor("3rd VWAP Boulevard"));
rVW1.SetHiding(ContStat); rVW2.SetHiding(V2 or ContStat); rVW3.SetHiding(V3 or ContStat); 
cVW1.SetHiding(!ContStat); cVW2.SetHiding(V2 or !ContStat); cVW3.SetHiding(V3 or !ContStat);

AddLabel(show_Labels,(if DayBarChoice then if IndepDyn then "[MAX Day" else "[Day" else "[Bar") + ", " + (if ContStat then "Continuous] " else "Static] ") , color.LIGHT_GRAY);
AddLabel(show_Labels and show_Spacers, " ", Color.BLACK);
AddLabel(show_Labels," VWAP.BLVD — " + Round(If(ContStat, cVW1, rVW1),2) + " ", if ContStat then cVW1.TakeValueColor() else rVW1.TakeValueColor());
AddLabel(show_Labels and show_Spacers, " ", Color.BLACK);
AddLabel(show_Labels and !V2, " VW[2]: " + Round(If(ContStat, cVW2, rVW2),2) + " ", if ContStat then cVW2.TakeValueColor() else rVW2.TakeValueColor());
AddLabel(show_Labels and !V2 and show_Spacers, " ", Color.BLACK);
AddLabel(show_Labels and !V3, " VW[3]: " + Round(If(ContStat, cVW3, rVW3),2) + " ", if ContStat then cVW3.TakeValueColor() else rVW3.TakeValueColor());
AddLabel(show_Labels and !V3 and show_Spacers, " ", Color.BLACK);

def yy1 = CustomGetValue(GetYear() % 100, If(DayBarChoice, If(IndepDyn,maxBarNo - B1,offset_1D), maxBarNo - barNoHi_1));
def mm1 = CustomGetValue(GetMonth(), If(DayBarChoice, If(IndepDyn,maxBarNo - B1,offset_1D), maxBarNo - barNoHi_1));
def dd1 = CustomGetValue(GetDayOfMonth(GetYYYYMMDD()), If(DayBarChoice, If(IndepDyn,maxBarNo - B1,offset_1D), maxBarNo - barNoHi_1));
def yy2 = CustomGetValue(GetYear() % 100, If(DayBarChoice, If(IndepDyn,maxBarNo - B2,offset_2D), maxBarNo - barNoHi_2));
def mm2 = CustomGetValue(GetMonth(), If(DayBarChoice, If(IndepDyn,maxBarNo - B2,offset_2D), maxBarNo - barNoHi_2));
def dd2 = CustomGetValue(GetDayOfMonth(GetYYYYMMDD()), If(DayBarChoice, If(IndepDyn,maxBarNo - B2,offset_2D), maxBarNo - barNoHi_2));
def yy3 = CustomGetValue(GetYear() % 100, If(DayBarChoice, If(IndepDyn,maxBarNo - B3,offset_3D), maxBarNo - barNoHi_3));
def mm3 = CustomGetValue(GetMonth(), If(DayBarChoice, If(IndepDyn,maxBarNo - B3,offset_3D), maxBarNo - barNoHi_3));
def dd3 = CustomGetValue(GetDayOfMonth(GetYYYYMMDD()), If(DayBarChoice, If(IndepDyn,maxBarNo - B3,offset_3D), maxBarNo - barNoHi_3));

AddVerticalLine(show_Lines and If(IndepDyn,if(DayBarChoice,barNo == B1e,barNo == barNoHi_1),barNo == If(DayBarChoice, fuse_1De, barNoHi_1)), "             HIGHEST VOLUME " + (if DayBarChoice then "DAY" else "BAR") + ("          " + (if mm1 > 9 then "" else "0") + mm1) + "." + (if dd1 > 9 then "" else "0") + dd1 + ".20" + yy1, GlobalColor("VWAP Boulevard"));
AddVerticalLine(!V2 and show_Lines and If(IndepDyn,if(DayBarChoice,barNo == B2e,barNo == barNoHi_2),barNo == If(DayBarChoice, fuse_2De, barNoHi_2)), "                 2nd BOULEVARD " + (if DayBarChoice then "DAY" else "BAR") + ("          " + (if mm2 > 9 then "" else "0") + mm2) + "." + (if dd2 > 9 then "" else "0") + dd2 + ".20" + yy2,GlobalColor("2nd VWAP Boulevard"));
AddVerticalLine(!V3 and show_Lines and If(IndepDyn,if(DayBarChoice,barNo == B3e,barNo == barNoHi_3),barNo == If(DayBarChoice, fuse_3De, barNoHi_3)), "                 3rd BOULEVARD " + (if DayBarChoice then "DAY" else "BAR") + ("          " + (if mm3 > 9 then "" else "0") + mm3) + "." + (if dd3 > 9 then "" else "0") + dd3 + ".20" + yy3,GlobalColor("3rd VWAP Boulevard"));

AddVerticalLine(show_Search_Range and barNo == If(IndepDyn,maxBarNo - length,NaN),"             Search Range Start — " + length + " bars ago",color.WHITE,curve.FIRM);

def i = 0; AddChartBubble(isLast[i] and show_Bubbles, Round(If(ContStat, cVW1, rVW1),2), "VW.BLVD", GlobalColor("VWAP Boulevard"));
AddChartBubble(isLast[i] and !V2 and show_Bubbles, Round(If(ContStat, cVW2, rVW2),2), "VW.BLVD.2", GlobalColor("2nd VWAP Boulevard"));
AddChartBubble(isLast[i] and !V3 and show_Bubbles, Round(If(ContStat, cVW3, rVW3),2), "VW.BLVD.3", GlobalColor("3rd VWAP Boulevard"));